glue\_genes.glue\_genomics\_data.multires\_data.MultiResolutionData
===================================================================

.. currentmodule:: glue_genes.glue_genomics_data.multires_data

.. autoclass:: MultiResolutionData

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MultiResolutionData.__init__
      ~MultiResolutionData.add_component
      ~MultiResolutionData.add_component_link
      ~MultiResolutionData.add_subset
      ~MultiResolutionData.broadcast
      ~MultiResolutionData.component_ids
      ~MultiResolutionData.compute_fixed_resolution_buffer
      ~MultiResolutionData.compute_histogram
      ~MultiResolutionData.compute_statistic
      ~MultiResolutionData.dtype
      ~MultiResolutionData.find_component_id
      ~MultiResolutionData.get_component
      ~MultiResolutionData.get_data
      ~MultiResolutionData.get_kind
      ~MultiResolutionData.get_mask
      ~MultiResolutionData.get_object
      ~MultiResolutionData.get_selection_definition
      ~MultiResolutionData.get_subset_object
      ~MultiResolutionData.join_on_key
      ~MultiResolutionData.new_subset
      ~MultiResolutionData.register_to_hub
      ~MultiResolutionData.remove_component
      ~MultiResolutionData.reorder_components
      ~MultiResolutionData.setup_cid_lookups
      ~MultiResolutionData.to_dataframe
      ~MultiResolutionData.update_components
      ~MultiResolutionData.update_id
      ~MultiResolutionData.update_values_from_data
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MultiResolutionData.components
      ~MultiResolutionData.coordinate_components
      ~MultiResolutionData.coordinate_links
      ~MultiResolutionData.coords
      ~MultiResolutionData.data
      ~MultiResolutionData.derived_components
      ~MultiResolutionData.derived_links
      ~MultiResolutionData.externally_derivable_components
      ~MultiResolutionData.label
      ~MultiResolutionData.links
      ~MultiResolutionData.main_components
      ~MultiResolutionData.ndim
      ~MultiResolutionData.pixel_aligned_data
      ~MultiResolutionData.pixel_component_ids
      ~MultiResolutionData.primary_components
      ~MultiResolutionData.shape
      ~MultiResolutionData.size
      ~MultiResolutionData.subsets
      ~MultiResolutionData.visible_components
      ~MultiResolutionData.world_component_ids
   
   